@@ -284,7 +284,7 @@ class SendScreen(CScreen):
             self.app.show_error(str(e))
             return
         if rbf:
-            tx.set_sequence(0)
+            tx.set_rbf(True)
         fee = tx.get_fee()
         msg = [
             _("Amount to be sent") + ": " + self.app.format_amount_and_units(amount),
